Package: amregtest
Title: Runs Allelematch Regression Tests
Version: 1.1.0
Date: 2026-07-04
Authors@R: c(
    person("Department of Wildlife, Fish and Environmental Studies at Swedish University of Agricultural Sciences",
           role = "cph"),
    person("Göran", "Spong", email = "Goran.Spong@slu.se", role = "cph",
           comment = "Senior Lecturer at the Department of Wildlife, Fish and Environmental Studies"),
    person("Paul", "Galpern", email = "pgalpern@gmail.com", role = "ctb",
           comment = "Author of the excellent package 'allelematch' from which the five amExample data files have been copied under MIT license"),
    person("Torvald", "Staxler", email = "torvald.staxler@telia.com", role = c("aut", "cre")))
Description: Automates regression testing of package 'allelematch'. Over
    2500 tests cover all functions in 'allelematch', reproduce the
    examples from the documentation, and include negative tests. The
    implementation is based on 'testthat'.
License: MIT + file LICENSE
URL: https://github.com/torstax/amregtest
BugReports: https://github.com/torstax/amregtest/issues
Depends: R (>= 3.5), allelematch
Imports: digest, R6, remotes, testthat (>= 3.0.0), utils, withr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-04 19:13:38 UTC; Torva
Author: Department of Wildlife, Fish and Environmental Studies at Swedish
    University of Agricultural Sciences [cph],
  Göran Spong [cph] (Senior Lecturer at the Department of Wildlife, Fish
    and Environmental Studies),
  Paul Galpern [ctb] (Author of the excellent package 'allelematch' from
    which the five amExample data files have been copied under MIT
    license),
  Torvald Staxler [aut, cre]
Maintainer: Torvald Staxler <torvald.staxler@telia.com>
Repository: CRAN
Date/Publication: 2026-07-04 23:10:14 UTC
Built: R 4.5.2; ; 2026-07-05 02:52:11 UTC; unix
