# Generated by roxygen2: do not edit by hand

export(artList)
export(artRun)
export(artVersion)
import(allelematch)
import(digest)
import(remotes)
import(testthat)
import(utils)
import(withr)
importFrom(R6,R6Class)
