# Loop the Loop

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataMini, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 3 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity guessMorphology
      1      1.0000000 0.0000000              0       4      4            0             0        FALSE           0.083              7.3        ZeroFlat
      2      0.8333333 0.1666667              1       4      4            0             0         TRUE           0.083              7.3        ZeroFlat
      3      0.6666667 0.3333333              2       4      4            0             0        FALSE           0.083              7.3        ZeroFlat

---

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataExample1, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 10 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity   guessMorphology
      1           1.00      0.00              0      20     13            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      2           0.95      0.05              1      20     13            0             2        FALSE           0.005              6.1 ZeroSecondMinimum
      3           0.90      0.10              2      20     12            0             0         TRUE           0.005              6.1 ZeroSecondMinimum
      4           0.85      0.15              3      20     12            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      5           0.80      0.20              4      20     12            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      6           0.75      0.25              5      20     12            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      7           0.70      0.30              6      20     12            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      8           0.65      0.35              7      20     12            0             0        FALSE           0.005              6.1 ZeroSecondMinimum
      9           0.60      0.40              8      20     12            0             1        FALSE           0.005              6.1 ZeroSecondMinimum

---

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataExample2, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 10 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity   guessMorphology
      1           1.00      0.00              0     148    140            0             0        FALSE           0.046              7.9 ZeroSecondMinimum
      2           0.95      0.05              1     148    136            0            25        FALSE           0.046              7.9 ZeroSecondMinimum
      3           0.90      0.10              2     148    122            0            33        FALSE           0.046              7.9 ZeroSecondMinimum
      4           0.85      0.15              3     148    100            0             0         TRUE           0.046              7.9 ZeroSecondMinimum
      5           0.80      0.20              4     148     99            0             0        FALSE           0.046              7.9 ZeroSecondMinimum
      6           0.75      0.25              5     148     99            0             1        FALSE           0.046              7.9 ZeroSecondMinimum
      7           0.70      0.30              6     148     98            0             1        FALSE           0.046              7.9 ZeroSecondMinimum
      8           0.65      0.35              7     148     98            0            14        FALSE           0.046              7.9 ZeroSecondMinimum
      9           0.60      0.40              8     148     89            0            30        FALSE           0.046              7.9 ZeroSecondMinimum

---

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataExample3, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 10 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity      guessMorphology
      1           1.00      0.00              0     319    291            0             0        FALSE           0.097              8.2 NonZeroSecondMinimum
      2           0.95      0.05              1     319    281            0            97        FALSE           0.097              8.2 NonZeroSecondMinimum
      3           0.90      0.10              2     319    212            0           103        FALSE           0.097              8.2 NonZeroSecondMinimum
      4           0.85      0.15              3     319    159            0            77        FALSE           0.097              8.2 NonZeroSecondMinimum
      5           0.80      0.20              4     319    120            0            31        FALSE           0.097              8.2 NonZeroSecondMinimum
      6           0.75      0.25              5     319    109            0            25        FALSE           0.097              8.2 NonZeroSecondMinimum
      7           0.70      0.30              6     319    100            2             4         TRUE           0.097              8.2 NonZeroSecondMinimum
      8           0.65      0.35              7     319     93            7            12        FALSE           0.097              8.2 NonZeroSecondMinimum
      9           0.60      0.40              8     319     93            2            75        FALSE           0.097              8.2 NonZeroSecondMinimum

---

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataExample4, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 10 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity guessMorphology
      1           1.00      0.00              0     307    307            0             0        FALSE           0.199              4.8 NoSecondMinimum
      2           0.95      0.05              1     307    307            0            42         TRUE           0.199              4.8 NoSecondMinimum
      3           0.90      0.10              2     307    283            0            92        FALSE           0.199              4.8 NoSecondMinimum
      4           0.85      0.15              3     307    228            1            99        FALSE           0.199              4.8 NoSecondMinimum
      5           0.80      0.20              4     307    180            1           110        FALSE           0.199              4.8 NoSecondMinimum
      6           0.75      0.25              5     307    137            4           122        FALSE           0.199              4.8 NoSecondMinimum
      7           0.70      0.30              6     307     99            1           153        FALSE           0.199              4.8 NoSecondMinimum
      8           0.65      0.35              7     307     66            8           196        FALSE           0.199              4.8 NoSecondMinimum
      9           0.60      0.40              8     307     39           10           234        FALSE           0.199              4.8 NoSecondMinimum

---

    Code
      cat(cmdstr)
    Output
      amUniqueProfile(amdataExample5, doPlot=FALSE, verbose=FALSE)

---

    Code
      cat(ret)
    Output
      allelematch:  assuming genotype columns are in pairs, representing 10 loci
        matchThreshold cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity      guessMorphology
      1           1.00      0.00              0     335    253            0             0        FALSE           0.064              6.4 NonZeroSecondMinimum
      2           0.95      0.05              1     335    233            0            95        FALSE           0.064              6.4 NonZeroSecondMinimum
      3           0.90      0.10              2     335    189            0            65        FALSE           0.064              6.4 NonZeroSecondMinimum
      4           0.85      0.15              3     335    165            1            32         TRUE           0.064              6.4 NonZeroSecondMinimum
      5           0.80      0.20              4     335    154            0            48        FALSE           0.064              6.4 NonZeroSecondMinimum
      6           0.75      0.25              5     335    136            2           103        FALSE           0.064              6.4 NonZeroSecondMinimum
      7           0.70      0.30              6     335    106            1           163        FALSE           0.064              6.4 NonZeroSecondMinimum
      8           0.65      0.35              7     335     74            3           234        FALSE           0.064              6.4 NonZeroSecondMinimum
      9           0.60      0.40              8     335     40            4           237        FALSE           0.064              6.4 NonZeroSecondMinimum

---

    Code
      print(obj)
    Output
        matchThreshold  cutHeight alleleMismatch samples unique unclassified multipleMatch guessOptimum missingDataLoad allelicDiversity      guessMorphology
      1      1.0000000 0.00000000              0     335    265            0             0        FALSE           0.095              6.1 NonZeroSecondMinimum
      2      0.9523810 0.04761905              1     335    240            0            79        FALSE           0.095              6.1 NonZeroSecondMinimum
      3      0.9047619 0.09523810              2     335    195            1            57        FALSE           0.095              6.1 NonZeroSecondMinimum
      4      0.8571429 0.14285714              3     335    171            3            11         TRUE           0.095              6.1 NonZeroSecondMinimum
      5      0.8095238 0.19047619              4     335    155            1            41        FALSE           0.095              6.1 NonZeroSecondMinimum
      6      0.7619048 0.23809524              5     335    141            1            62        FALSE           0.095              6.1 NonZeroSecondMinimum
      7      0.7142857 0.28571429              6     335    115            2           123        FALSE           0.095              6.1 NonZeroSecondMinimum
      8      0.6666667 0.33333333              7     335     84           17            70        FALSE           0.095              6.1 NonZeroSecondMinimum
      9      0.6190476 0.38095238              8     335     45           26           176        FALSE           0.095              6.1 NonZeroSecondMinimum

